==> cryptocom_exchange-0.12.0.tar.gz: cryptocom_exchange-0.12.0/src/cryptocom/exchange/coins.py <==
from .structs import Coin

AAVE = Coin("AAVE")
ACA = Coin("ACA")
ACH = Coin("ACH")
ADA = Coin("ADA")
AERGO = Coin("AERGO")
AGLD = Coin("AGLD")
AIOZ = Coin("AIOZ")
AKT = Coin("AKT")
ALGO = Coin("ALGO")
ALI = Coin("ALI")
ALICE = Coin("ALICE")
ALPHA = Coin("ALPHA")
AMP = Coin("AMP")
ANC = Coin("ANC")
ANKR = Coin("ANKR")
ANY = Coin("ANY")
APE = Coin("APE")
API3 = Coin("API3")
AR = Coin("AR")
ARPA = Coin("ARPA")
ASTR = Coin("ASTR")
ATOM = Coin("ATOM")
AUDIO = Coin("AUDIO")
AURORA = Coin("AURORA")
AUTO = Coin("AUTO")
AVAX = Coin("AVAX")
AXS = Coin("AXS")
BADGER = Coin("BADGER")
BAL = Coin("BAL")
BAND = Coin("BAND")
BAT = Coin("BAT")
BCH = Coin("BCH")
BICO = Coin("BICO")
BIFI = Coin("BIFI")
BNT = Coin("BNT")
BOBA = Coin("BOBA")
BOND = Coin("BOND")
BOSON = Coin("BOSON")
BRZ = Coin("BRZ")
BTC = Coin("BTC")
BUSD = Coin("BUSD")
C98 = Coin("C98")
CELR = Coin("CELR")
CHESS = Coin("CHESS")
CHR = Coin("CHR")
CHZ = Coin("CHZ")
CKB = Coin("CKB")
COMP = Coin("COMP")
COTI = Coin("COTI")
CQT = Coin("CQT")
CRO = Coin("CRO")
CRPT = Coin("CRPT")
CRV = Coin("CRV")
CSPR = Coin("CSPR")
CTSI = Coin("CTSI")
CUDOS = Coin("CUDOS")
CVX = Coin("CVX")
DAI = Coin("DAI")
DAR = Coin("DAR")
DERC = Coin("DERC")
DGB = Coin("DGB")
DIA = Coin("DIA")
DINO = Coin("DINO")
DOGE = Coin("DOGE")
DOT = Coin("DOT")
DYDX = Coin("DYDX")
EFI = Coin("EFI")
EGLD = Coin("EGLD")
ELON = Coin("ELON")
ENJ = Coin("ENJ")
ENS = Coin("ENS")
EOS = Coin("EOS")
EPS = Coin("EPS")
EPX = Coin("EPX")
ERN = Coin("ERN")
ETC = Coin("ETC")
ETH = Coin("ETH")
ETHW = Coin("ETHW")
FARM = Coin("FARM")
FER = Coin("FER")
FET = Coin("FET")
FIL = Coin("FIL")
FITFI = Coin("FITFI")
FLOW = Coin("FLOW")
FLUX = Coin("FLUX")
FORTH = Coin("FORTH")
FTM = Coin("FTM")
FXS = Coin("FXS")
GAL = Coin("GAL")
GALA = Coin("GALA")
GARI = Coin("GARI")
GHST = Coin("GHST")
GLM = Coin("GLM")
GLMR = Coin("GLMR")
GMT = Coin("GMT")
GMX = Coin("GMX")
GODS = Coin("GODS")
GRT = Coin("GRT")
GTC = Coin("GTC")
GUSD = Coin("GUSD")
HBAR = Coin("HBAR")
HERO = Coin("HERO")
HIGH = Coin("HIGH")
HNT = Coin("HNT")
HOD = Coin("HOD")
HOT = Coin("HOT")
HUSD = Coin("HUSD")
ICP = Coin("ICP")
ICX = Coin("ICX")
ILV = Coin("ILV")
IMX = Coin("IMX")
INJ = Coin("INJ")
IOTX = Coin("IOTX")
IQ = Coin("IQ")
JASMY = Coin("JASMY")
JOE = Coin("JOE")
KAVA = Coin("KAVA")
KEEP = Coin("KEEP")
KLAY = Coin("KLAY")
KNC = Coin("KNC")
KP3R = Coin("KP3R")
KRL = Coin("KRL")
KSM = Coin("KSM")
LDO = Coin("LDO")
LINK = Coin("LINK")
LOKA = Coin("LOKA")
LPT = Coin("LPT")
LRC = Coin("LRC")
LSK = Coin("LSK")
LTC = Coin("LTC")
LUNA = Coin("LUNA")
LUNA2 = Coin("LUNA2")
LUNC = Coin("LUNC")
MANA = Coin("MANA")
MASK = Coin("MASK")
MATIC = Coin("MATIC")
MBL = Coin("MBL")
MC = Coin("MC")
MCO = Coin("MCO")
MDT = Coin("MDT")
METIS = Coin("METIS")
MINA = Coin("MINA")
MIR = Coin("MIR")
MKR = Coin("MKR")
MLN = Coin("MLN")
MMF = Coin("MMF")
MOVR = Coin("MOVR")
MTD = Coin("MTD")
MULTI = Coin("MULTI")
MXC = Coin("MXC")
NANO = Coin("NANO")
NEAR = Coin("NEAR")
NEO = Coin("NEO")
NKN = Coin("NKN")
NMR = Coin("NMR")
NU = Coin("NU")
OCEAN = Coin("OCEAN")
OGN = Coin("OGN")
OGV = Coin("OGV")
OLE = Coin("OLE")
OMG = Coin("OMG")
ONE = Coin("ONE")
ONEINCH = Coin("1INCH")
ONT = Coin("ONT")
OP = Coin("OP")
OXT = Coin("OXT")
PAX = Coin("PAX")
PAXG = Coin("PAXG")
PENDLE = Coin("PENDLE")
PERP = Coin("PERP")
PLA = Coin("PLA")
POLS = Coin("POLS")
POLY = Coin("POLY")
POLYX = Coin("POLYX")
POND = Coin("POND")
POWR = Coin("POWR")
PRQ = Coin("PRQ")
PYR = Coin("PYR")
QI = Coin("QI")
QNT = Coin("QNT")
QRDO = Coin("QRDO")
QTUM = Coin("QTUM")
QUICK = Coin("QUICK")
RAD = Coin("RAD")
RADAR = Coin("RADAR")
RARE = Coin("RARE")
RARI = Coin("RARI")
RAY = Coin("RAY")
REEF = Coin("REEF")
REN = Coin("REN")
REP = Coin("REP")
REQ = Coin("REQ")
RGT = Coin("RGT")
RLC = Coin("RLC")
RLY = Coin("RLY")
RNDR = Coin("RNDR")
RSR = Coin("RSR")
RUNE = Coin("RUNE")
RVN = Coin("RVN")
SAND = Coin("SAND")
SC = Coin("SC")
SDN = Coin("SDN")
SGB = Coin("SGB")
SHIB = Coin("SHIB")
SKL = Coin("SKL")
SLP = Coin("SLP")
SNT = Coin("SNT")
SNX = Coin("SNX")
SOL = Coin("SOL")
SPELL = Coin("SPELL")
SPS = Coin("SPS")
SRM = Coin("SRM")
STORJ = Coin("STORJ")
STRAX = Coin("STRAX")
STX = Coin("STX")
SUPER = Coin("SUPER")
SUSHI = Coin("SUSHI")
T = Coin("T")
TFUEL = Coin("TFUEL")
THETA = Coin("THETA")
TONIC = Coin("TONIC")
TRB = Coin("TRB")
TRIBE = Coin("TRIBE")
TRU = Coin("TRU")
TUSD = Coin("TUSD")
UMA = Coin("UMA")
UNFI = Coin("UNFI")
UNI = Coin("UNI")
USDC = Coin("USDC")
USDP = Coin("USDP")
USDT = Coin("USDT")
VELO = Coin("VELO")
VET = Coin("VET")
VOXEL = Coin("VOXEL")
VRA = Coin("VRA")
VTHO = Coin("VTHO")
VVS = Coin("VVS")
WAVE = Coin("WAVE")
WAVES = Coin("WAVES")
WAXP = Coin("WAXP")
WBTC = Coin("WBTC")
WEMIX = Coin("WEMIX")
WOO = Coin("WOO")
XLM = Coin("XLM")
XNO = Coin("XNO")
XRP = Coin("XRP")
XTZ = Coin("XTZ")
XYO = Coin("XYO")
YFI = Coin("YFI")
YGG = Coin("YGG")
ZBC = Coin("ZBC")
ZED = Coin("ZED")
ZIL = Coin("ZIL")
ZRX = Coin("ZRX")


def all():
    return [
        value for name, value in globals().items() if isinstance(value, Coin)
    ]

==> cryptocom_exchange-0.13.0.tar.gz: cryptocom_exchange-0.13.0/src/cryptocom/exchange/coins.py <==
from .structs import Coin

AAVE = Coin("AAVE")
ACA = Coin("ACA")
ACH = Coin("ACH")
ADA = Coin("ADA")
AERGO = Coin("AERGO")
AGLD = Coin("AGLD")
AIOZ = Coin("AIOZ")
AKT = Coin("AKT")
ALGO = Coin("ALGO")
ALI = Coin("ALI")
ALICE = Coin("ALICE")
ALPHA = Coin("ALPHA")
AMP = Coin("AMP")
ANKR = Coin("ANKR")
APE = Coin("APE")
API3 = Coin("API3")
APT = Coin("APT")
AR = Coin("AR")
ARPA = Coin("ARPA")
ASTR = Coin("ASTR")
ATOM = Coin("ATOM")
AUDIO = Coin("AUDIO")
AURORA = Coin("AURORA")
AUTO = Coin("AUTO")
AVAX = Coin("AVAX")
AXS = Coin("AXS")
BADGER = Coin("BADGER")
BAL = Coin("BAL")
BAND = Coin("BAND")
BAT = Coin("BAT")
BCH = Coin("BCH")
BICO = Coin("BICO")
BIFI = Coin("BIFI")
BNT = Coin("BNT")
BOND = Coin("BOND")
BOSON = Coin("BOSON")
BRZ = Coin("BRZ")
BTC = Coin("BTC")
C98 = Coin("C98")
CELR = Coin("CELR")
CHESS = Coin("CHESS")
CHR = Coin("CHR")
CHZ = Coin("CHZ")
CKB = Coin("CKB")
COMP = Coin("COMP")
COTI = Coin("COTI")
CQT = Coin("CQT")
CRO = Coin("CRO")
CRPT = Coin("CRPT")
CRV = Coin("CRV")
CSPR = Coin("CSPR")
CTSI = Coin("CTSI")
CUDOS = Coin("CUDOS")
CVX = Coin("CVX")
DAI = Coin("DAI")
DAR = Coin("DAR")
DERC = Coin("DERC")
DGB = Coin("DGB")
DIA = Coin("DIA")
DOGE = Coin("DOGE")
DOT = Coin("DOT")
DYDX = Coin("DYDX")
EFI = Coin("EFI")
EGLD = Coin("EGLD")
ELON = Coin("ELON")
ENJ = Coin("ENJ")
ENS = Coin("ENS")
EOS = Coin("EOS")
EPX = Coin("EPX")
ERN = Coin("ERN")
ETC = Coin("ETC")
ETH = Coin("ETH")
ETHW = Coin("ETHW")
FARM = Coin("FARM")
FER = Coin("FER")
FET = Coin("FET")
FIL = Coin("FIL")
FITFI = Coin("FITFI")
FLOW = Coin("FLOW")
FLUX = Coin("FLUX")
FORTH = Coin("FORTH")
FTM = Coin("FTM")
FXS = Coin("FXS")
GAL = Coin("GAL")
GALA = Coin("GALA")
GARI = Coin("GARI")
GHST = Coin("GHST")
GLM = Coin("GLM")
GLMR = Coin("GLMR")
GMX = Coin("GMX")
GODS = Coin("GODS")
GRT = Coin("GRT")
GTC = Coin("GTC")
HBAR = Coin("HBAR")
HERO = Coin("HERO")
HIGH = Coin("HIGH")
HNT = Coin("HNT")
HOD = Coin("HOD")
HOT = Coin("HOT")
ICP = Coin("ICP")
ICX = Coin("ICX")
ILV = Coin("ILV")
IMX = Coin("IMX")
INJ = Coin("INJ")
IOTX = Coin("IOTX")
IQ = Coin("IQ")
JASMY = Coin("JASMY")
JOE = Coin("JOE")
KAVA = Coin("KAVA")
KLAY = Coin("KLAY")
KNC = Coin("KNC")
KP3R = Coin("KP3R")
KRL = Coin("KRL")
KSM = Coin("KSM")
LDO = Coin("LDO")
LINK = Coin("LINK")
LOKA = Coin("LOKA")
LPT = Coin("LPT")
LRC = Coin("LRC")
LSK = Coin("LSK")
LTC = Coin("LTC")
LUNA2 = Coin("LUNA2")
LUNC = Coin("LUNC")
MANA = Coin("MANA")
MASK = Coin("MASK")
MATIC = Coin("MATIC")
MBL = Coin("MBL")
MC = Coin("MC")
MDT = Coin("MDT")
METIS = Coin("METIS")
MINA = Coin("MINA")
MKR = Coin("MKR")
MLN = Coin("MLN")
MMF = Coin("MMF")
MOVR = Coin("MOVR")
MTD = Coin("MTD")
MULTI = Coin("MULTI")
MXC = Coin("MXC")
NEAR = Coin("NEAR")
NEO = Coin("NEO")
NKN = Coin("NKN")
NMR = Coin("NMR")
OCEAN = Coin("OCEAN")
OGN = Coin("OGN")
OLE = Coin("OLE")
OMG = Coin("OMG")
ONE = Coin("ONE")
ONEINCH = Coin("ONEINCH")
ONT = Coin("ONT")
OP = Coin("OP")
OXT = Coin("OXT")
PAXG = Coin("PAXG")
PENDLE = Coin("PENDLE")
PERP = Coin("PERP")
PLA = Coin("PLA")
POLS = Coin("POLS")
POND = Coin("POND")
POWR = Coin("POWR")
PRQ = Coin("PRQ")
PYR = Coin("PYR")
QI = Coin("QI")
QNT = Coin("QNT")
QRDO = Coin("QRDO")
QTUM = Coin("QTUM")
QUICK = Coin("QUICK")
RAD = Coin("RAD")
RADAR = Coin("RADAR")
RARE = Coin("RARE")
RARI = Coin("RARI")
RAY = Coin("RAY")
REEF = Coin("REEF")
REN = Coin("REN")
REP = Coin("REP")
REQ = Coin("REQ")
RLC = Coin("RLC")
RLY = Coin("RLY")
RNDR = Coin("RNDR")
RSR = Coin("RSR")
RUNE = Coin("RUNE")
SAND = Coin("SAND")
SC = Coin("SC")
SDN = Coin("SDN")
SHIB = Coin("SHIB")
SKL = Coin("SKL")
SLP = Coin("SLP")
SNT = Coin("SNT")
SNX = Coin("SNX")
SOL = Coin("SOL")
SPELL = Coin("SPELL")
SPS = Coin("SPS")
SRM = Coin("SRM")
STORJ = Coin("STORJ")
STRAX = Coin("STRAX")
STX = Coin("STX")
SUPER = Coin("SUPER")
SUSHI = Coin("SUSHI")
T = Coin("T")
TFUEL = Coin("TFUEL")
THETA = Coin("THETA")
TONIC = Coin("TONIC")
TRB = Coin("TRB")
TRIBE = Coin("TRIBE")
TRU = Coin("TRU")
UMA = Coin("UMA")
UNFI = Coin("UNFI")
UNI = Coin("UNI")
USD = Coin("USD")
USDT = Coin("USDT")
VELO = Coin("VELO")
VET = Coin("VET")
VOXEL = Coin("VOXEL")
VRA = Coin("VRA")
VTHO = Coin("VTHO")
VVS = Coin("VVS")
WAVES = Coin("WAVES")
WAXP = Coin("WAXP")
WBTC = Coin("WBTC")
WEMIX = Coin("WEMIX")
WOO = Coin("WOO")
XLM = Coin("XLM")
XNO = Coin("XNO")
XRP = Coin("XRP")
XTZ = Coin("XTZ")
XYO = Coin("XYO")
YFI = Coin("YFI")
YGG = Coin("YGG")
ZBC = Coin("ZBC")
ZED = Coin("ZED")
ZIL = Coin("ZIL")
ZRX = Coin("ZRX")


def all():
    return [
        value for name, value in globals().items() if isinstance(value, Coin)
    ]
